allowsAny method
Returns true if this constraint allows any of the versions that other
allows.
Implementation
@override
bool allowsAny(VersionConstraint other) => other.allows(this);
Returns true if this constraint allows any of the versions that other
allows.
@override
bool allowsAny(VersionConstraint other) => other.allows(this);