any property
A VersionConstraint that allows all versions.
Note: This property shouldn't be reassigned.
It will be made final in a future release.
Implementation
static VersionConstraint any = VersionRange();
A VersionConstraint that allows all versions.
Note: This property shouldn't be reassigned.
It will be made final in a future release.
static VersionConstraint any = VersionRange();