empty property
A VersionConstraint that allows no versions -- the empty set.
Note: This property shouldn't be reassigned.
It will be made final in a future release.
Implementation
static VersionConstraint empty = const _EmptyVersion();
A VersionConstraint that allows no versions -- the empty set.
Note: This property shouldn't be reassigned.
It will be made final in a future release.
static VersionConstraint empty = const _EmptyVersion();